==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepResourceFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StepResourceFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResourceFluent<A>{
  public StepResourceFluentImpl() {
  }
  public StepResourceFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResource instance) {
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withManifest(instance.getManifest()); 
    this.withName(instance.getName()); 
    this.withSourceName(instance.getSourceName()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String group;
  private java.lang.String kind;
  private java.lang.String manifest;
  private java.lang.String name;
  private java.lang.String sourceName;
  private java.lang.String sourceNamespace;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getGroup() {
    return this.group;
  }
  public A withGroup(java.lang.String group) {
    this.group=group; return (A) this;
  }
  public java.lang.Boolean hasGroup() {
    return this.group != null;
  }
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0) {
    return (A)withGroup(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public java.lang.String getManifest() {
    return this.manifest;
  }
  public A withManifest(java.lang.String manifest) {
    this.manifest=manifest; return (A) this;
  }
  public java.lang.Boolean hasManifest() {
    return this.manifest != null;
  }
  
  /**
   * Method is deprecated. use withManifest instead.
   */
  @java.lang.Deprecated
  public A withNewManifest(java.lang.String arg0) {
    return (A)withManifest(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getSourceName() {
    return this.sourceName;
  }
  public A withSourceName(java.lang.String sourceName) {
    this.sourceName=sourceName; return (A) this;
  }
  public java.lang.Boolean hasSourceName() {
    return this.sourceName != null;
  }
  
  /**
   * Method is deprecated. use withSourceName instead.
   */
  @java.lang.Deprecated
  public A withNewSourceName(java.lang.String arg0) {
    return (A)withSourceName(new String(arg0));
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StepResourceFluentImpl that = (StepResourceFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (manifest != null ? !manifest.equals(that.manifest) :that.manifest != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (sourceName != null ? !sourceName.equals(that.sourceName) :that.sourceName != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  manifest,  name,  sourceName,  sourceNamespace,  version,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepResourceFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StepResourceFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResourceFluent<A>{
  public StepResourceFluentImpl() {
  }
  public StepResourceFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepResource instance) {
    this.withGroup(instance.getGroup()); 
    this.withKind(instance.getKind()); 
    this.withManifest(instance.getManifest()); 
    this.withName(instance.getName()); 
    this.withSourceName(instance.getSourceName()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String group;
  private java.lang.String kind;
  private java.lang.String manifest;
  private java.lang.String name;
  private java.lang.String sourceName;
  private java.lang.String sourceNamespace;
  private java.lang.String version;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getGroup() {
    return this.group;
  }
  public A withGroup(java.lang.String group) {
    this.group=group; return (A) this;
  }
  public java.lang.Boolean hasGroup() {
    return this.group != null;
  }
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0) {
    return (A)withGroup(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public java.lang.String getManifest() {
    return this.manifest;
  }
  public A withManifest(java.lang.String manifest) {
    this.manifest=manifest; return (A) this;
  }
  public java.lang.Boolean hasManifest() {
    return this.manifest != null;
  }
  
  /**
   * Method is deprecated. use withManifest instead.
   */
  @java.lang.Deprecated
  public A withNewManifest(java.lang.String arg0) {
    return (A)withManifest(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getSourceName() {
    return this.sourceName;
  }
  public A withSourceName(java.lang.String sourceName) {
    this.sourceName=sourceName; return (A) this;
  }
  public java.lang.Boolean hasSourceName() {
    return this.sourceName != null;
  }
  
  /**
   * Method is deprecated. use withSourceName instead.
   */
  @java.lang.Deprecated
  public A withNewSourceName(java.lang.String arg0) {
    return (A)withSourceName(new String(arg0));
  }
  public java.lang.String getSourceNamespace() {
    return this.sourceNamespace;
  }
  public A withSourceNamespace(java.lang.String sourceNamespace) {
    this.sourceNamespace=sourceNamespace; return (A) this;
  }
  public java.lang.Boolean hasSourceNamespace() {
    return this.sourceNamespace != null;
  }
  
  /**
   * Method is deprecated. use withSourceNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewSourceNamespace(java.lang.String arg0) {
    return (A)withSourceNamespace(new String(arg0));
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public A withVersion(java.lang.String version) {
    this.version=version; return (A) this;
  }
  public java.lang.Boolean hasVersion() {
    return this.version != null;
  }
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0) {
    return (A)withVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StepResourceFluentImpl that = (StepResourceFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (manifest != null ? !manifest.equals(that.manifest) :that.manifest != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (sourceName != null ? !sourceName.equals(that.sourceName) :that.sourceName != null) return false;
    if (sourceNamespace != null ? !sourceNamespace.equals(that.sourceNamespace) :that.sourceNamespace != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  kind,  manifest,  name,  sourceName,  sourceNamespace,  version,  additionalProperties,  super.hashCode());
  }
  
}
